Struct amazon_sp_vendor_direct_fulfillment_orders::models::shipment_details::ShipmentDetails
source · [−]pub struct ShipmentDetails {
pub is_priority_shipment: bool,
pub is_scheduled_delivery_shipment: Option<bool>,
pub is_pslip_required: bool,
pub is_gift: Option<bool>,
pub ship_method: String,
pub shipment_dates: Box<ShipmentDates>,
pub message_to_customer: String,
}Expand description
ShipmentDetails : Shipment details required for the shipment.
Fields
is_priority_shipment: boolWhen true, this is a priority shipment.
is_scheduled_delivery_shipment: Option<bool>When true, this order is part of a scheduled delivery program.
is_pslip_required: boolWhen true, a packing slip is required to be sent to the customer.
is_gift: Option<bool>When true, the order contain a gift. Include the gift message and gift wrap information.
ship_method: StringShip method to be used for shipping the order. Amazon defines ship method codes indicating the shipping carrier and shipment service level. To see the full list of ship methods in use, including both the code and the friendly name, search the ‘Help’ section on Vendor Central for ‘ship methods’.
shipment_dates: Box<ShipmentDates>message_to_customer: StringMessage to customer for order status.
Implementations
sourceimpl ShipmentDetails
impl ShipmentDetails
sourcepub fn new(
is_priority_shipment: bool,
is_pslip_required: bool,
ship_method: String,
shipment_dates: ShipmentDates,
message_to_customer: String
) -> ShipmentDetails
pub fn new(
is_priority_shipment: bool,
is_pslip_required: bool,
ship_method: String,
shipment_dates: ShipmentDates,
message_to_customer: String
) -> ShipmentDetails
Shipment details required for the shipment.